@@ -1,7 +1,33 @@
-_help = help
-_print = print
+# top module functions
+all = help = None
 
-__keep__ = list(globals()) # Don't use word `__all__`, its will rewrite many times below.
+# base on built-in library
+from .cls import *
+from .dec import *
+from .new import *
+from .line import *
+from .useful import *
+from .windll import *
+
+# 3rd-library needed
+from .auto import *
+from .doc import *
+from .gui import *
+from .np import *
+
+
+def all():
+    import sys
+    import inspect
+    table = {}
+    for module, obj in globals().items():
+        if inspect.ismodule(obj) and obj.__name__.count('.') == 1:
+            for name in obj.__all__:
+                if name not in table:
+                    table[name] = module
+                elif name != '__all__':
+                    print("Warnning: '%s.%s' exist in '%s.%s'" % (module, name, table[name], name), file=sys.stderr)
+    return ['all', 'help'] + list(table)
 
 
 def help():
@@ -22,19 +48,4 @@ def help():
                     print("- %s = %r" % (k, v))
 
 
-# base on built-in library
-from .cls import *
-from .decorator import *
-from .line import *
-from .refact import *
-from .useful import *
-from .windll import *
-
-# 3rd-library needed
-from .auto import *
-from .doc import *
-from .gui import *
-from .np import *
-
-# __all__ = [k for k in globals() if k not in __keep__]
-__all__ = [k for k, v in globals().items() if k not in __keep__ and callable(v)]
+__all__ = all()
