@@ -4,6 +4,24 @@ import os
 import csv
 
 
+def num2str(cell):
+    if isinstance(cell, float) and cell.is_integer():
+        cell = int(cell)
+    return str(cell)
+
+
+def str2value(s):
+    try:
+        v = float(s)
+        if v.is_integer():
+            v = int(v)
+    except ValueError:
+        v = {'none': None, 'null': None, '': None,
+             'true': True, 'flase': False
+        }.get(s.lower(), s)
+    return v
+
+
 __all__ = list(globals())
 
 
@@ -12,7 +30,39 @@ __all__ = list(globals())
 # ---------------------------------------------------------------------------
 
 
-def WriteTxt(data, file, encoding='utf-8-sig'):
+def read(file):
+    try:
+        with open(file, encoding='u8') as f:
+            return f.read()
+    except UnicodeDecodeError:
+        with open(file) as f:
+            return f.read()
+
+
+def write(file, data):
+    os.makedirs(os.path.dirname(file), exist_ok=True)
+    with open(file, 'w', encoding='u8') as f:
+        f.write(data)
+
+
+def ReadIni(file, encoding='u8'):
+    import configparser
+    p = configparser.ConfigParser()
+    p.optionxform = str  # fix opinion can't read key with upper case
+    p.read(file, encoding=encoding)
+    return {s: dict(p.items(s)) for s in p.sections()}
+
+
+def WriteIni(file, dic, encoding='u8'):
+    import configparser
+    p = configparser.ConfigParser()
+    p.optionxform = str  # fix opinion can't read key with upper case
+    p.read_dict(dic)
+    with open(file, 'w', encoding=encoding) as f:
+        p.write(f, False)
+
+
+def WriteTxt(file, data, encoding='utf-8-sig'):
     with open(file, 'w', encoding=encoding) as f:
         f.write('\n'.join(','.join(str(cell) for cell in row) for row in data))
 
@@ -22,7 +72,7 @@ def ReadCsv(file, encoding='utf-8-sig'):
         return list(csv.reader(f))
 
 
-def WriteCsv(data, file, encoding='utf-8-sig', errors='ignore'):
+def WriteCsv(file, data, encoding='utf-8-sig', errors='ignore'):
     with open(file, 'w', newline='', encoding=encoding, errors=errors) as f:
         writer = csv.writer(f)
         writer.writerows(data)
@@ -33,7 +83,7 @@ def WriteCsv(data, file, encoding='utf-8-sig', errors='ignore'):
 # ---------------------------------------------------------------------------
 
 
-def WriteExcel(data, file, new_sheet='sheet1'):
+def WriteExcel(file, data, new_sheet='sheet1'):
     import xlwt
     xls = xlwt.Workbook('u8')
     sheet = xls.add_sheet(new_sheet, True)
@@ -98,13 +148,7 @@ def ReadExcel(file, merge_x=True, merge_y=True, strip_x=False):
         sheet_data = []
         for row in range(sheet.nrows):
             rows = [sheet_name] + sheet.row_values(row)
-            for c, cell in enumerate(rows):
-                if isinstance(cell, float):
-                    if cell.is_integer():
-                        rows[c] = str(int(cell))
-                    else:
-                        rows[c] = str(cell)
-            sheet_data.append(rows)
+            sheet_data.append(list(map(num2str, rows)))
         data.append(sheet_data)
 
     # only ".xls" type contain merge_info
@@ -113,6 +157,13 @@ def ReadExcel(file, merge_x=True, merge_y=True, strip_x=False):
     return data, merge
 
 
+def ReadSheet(file, index=0):
+    import xlrd
+    xls = xlrd.open_workbook(file)
+    sheet = xls.sheet_by_index(index)
+    return [list(map(num2str, sheet.row_values(row))) for row in range(sheet.nrows)]
+
+
 # ---------------------------------------------------------------------------
 # Word
 # ---------------------------------------------------------------------------
@@ -210,10 +261,6 @@ def ReadFiles(files, merge_x=True, merge_y=True, strip_x=False):
     return data
 
 
-def Unique(arr):
-    return [i for i, item in enumerate(arr) if arr.index(item) == i]
-
-
 __all__ = [k for k in globals() if k not in __all__]
 
 
